<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package adney
 */

if ( ! function_exists( 'adney_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function adney_posted_on() {
?>


<?php
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

	$byline = sprintf(
		esc_html_x( ' %s', 'post author', 'adney' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<div class="post_date montserrat-text uppercase">' . $posted_on . '</div>';
	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<i class="icon ion-chatbox-working"></i><span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a comment', 'adney' ), esc_html__( '1 Comment', 'adney' ), esc_html__( '% Comments', 'adney' ) );
		echo '</span>';
	}
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'adney' ) );
		if ( $categories_list && adney_categorized_blog() ) {
			printf( '<i class="icon ion-briefcase"></i><span> %1$s </span>', $categories_list ); // WPCS: XSS OK.
		}

	}
	echo '<i class="icon ion-ios-person"></i><span> ' . $byline . '</span>'; // WPCS: XSS OK.
}
endif;

if ( ! function_exists( 'adney_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function adney_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ' ', 'adney' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . esc_html__( 'Tagged: %1$s', 'adney' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'adney' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<div class="edit-link">',
		'</div>'
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function adney_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'adney_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'adney_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so adney_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so adney_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in adney_categorized_blog.
 */
function adney_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'adney_categories' );
}
add_action( 'edit_category', 'adney_category_transient_flusher' );
add_action( 'save_post',     'adney_category_transient_flusher' );
